==> haskell-project-template-0.2.0-72-i686.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-IivDjbLPBuLHFpCIlzeDfj
key: project-template-0.2.0-IivDjbLPBuLHFpCIlzeDfj
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.ProjectTemplate
abi: 26e2da8c7835a15690476a1f651a69ee
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/project-template-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-IivDjbLPBuLHFpCIlzeDfj
depends:
    base-4.10.0.0 base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    transformers-0.5.2.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz
    conduit-extra-1.1.16-KEf50o5RV3r5Z0A1OmC86V
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 containers-0.5.10.2
    filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             conduit-1.2.11-9uKDAPdSqMw2QUAecxU9lz=04052e0ff779aa08eefa6f6b9de183d0
             conduit-extra-1.1.16-KEf50o5RV3r5Z0A1OmC86V=64aac04225cc01d9fd30f349b8bbb76b
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-project-template-0.2.0-75-i686.pkg.tar.xz: usr/share/haskell/register/haskell-project-template.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: project-template
version: 0.2.0
id: project-template-0.2.0-5dzXnJftSFUEc83a8ZxmpU
key: project-template-0.2.0-5dzXnJftSFUEc83a8ZxmpU
license: BSD3
maintainer: michael@fpcomplete.com
homepage: https://github.com/fpco/haskell-ide
synopsis: Specify Haskell project templates and generate files
description:
    See initial blog post for explanation: <http://www.yesodweb.com/blog/2012/09/project-templates>
category: Development
author: Michael Snoyman
exposed: True
indefinite: False
exposed-modules:
    Text.ProjectTemplate
abi: b7f58e91144ae2d7cac0594526bd9925
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/project-template-0.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/project-template-0.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/project-template-0.2.0
hs-libraries: HSproject-template-0.2.0-5dzXnJftSFUEc83a8ZxmpU
depends:
    base-4.10.0.0 base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm
    text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz bytestring-0.10.8.2
    transformers-0.5.2.0 mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3
    conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1
    conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e
    resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9 containers-0.5.10.2
    filepath-1.4.1.2 directory-1.3.0.2
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             base64-bytestring-1.0.0.1-D9uFxOosRHvGwKtuClA6fm=b470a7d524cce39b639ac0b1fe2cc085
             text-1.2.2.2-KYRZgO9N4MoJ4sC5lMiKTz=b7786dac6fdbd4e62fbcd8f2e5703783
             bytestring-0.10.8.2=db54a9a10f4b3abcd860c80f928b2ae9
             transformers-0.5.2.0=c9bb94e07e5a6cae97f4e7452aafbf8b
             mtl-2.2.1-19EL8AGBsN3DnnOhrC9xY3=14e57a3b735adfe06c357bcc64de3dbd
             conduit-1.2.12-3TKiqrYwAuWAgXZB4yMkK1=60ad65370a9da57d3d90715264a4baf8
             conduit-extra-1.1.17-LlNYIlAZHtT6LyG0bML71e=8535fcdffdc059c10de789d083424da6
             resourcet-1.1.9-L2AvjA6mP5RDwDqcbBVGV9=2267b8435957f2f8210cd2fc45f80e4c
             containers-0.5.10.2=e51b78cedb073051e10b1c1314421145
             filepath-1.4.1.2=2a8b7688454d81e83f77ef81b74e0636
             directory-1.3.0.2=cfeb01f7201df723a8082d0da3163aee
haddock-interfaces: /usr/share/doc/haskell-project-template/html/project-template.haddock
haddock-html: /usr/share/doc/haskell-project-template/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
